# OneTimeUseActionChallengeResponse

The response to creating the OneTimeUseActionChallenge. This contains the newly created challenge, as well as the details necessary to answer it. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**challenge** | [**Challenge**](Challenge.md) |  | 
**one_time_use_challenge** | [**OneTimeUseActionChallenge**](OneTimeUseActionChallenge.md) |  | 
**answer_details** | [**[OneTimeUseActionChallengeAnswerDetail]**](OneTimeUseActionChallengeAnswerDetail.md) | A list of answers per actor | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


